@@ -8,6 +8,8 @@ test_that("If it works.", {
 
   model <- psycho::analyze(fit)
   values <- values(model)
-  testthat::expect_equal(round(values$Sepal.Width$Coef, 2), 0.8,
-                         tolerance = 0.05)
+  testthat::expect_equal(
+    round(values$Sepal.Width$Coef, 2), 0.8,
+    tolerance = 0.05
+  )
 })
